@@ -1,5 +1,137 @@
 package CSS::Tiny;
 
+# See POD at end for docs
+
+use strict;
+BEGIN {
+	require 5.005;
+	$CSS::Tiny::VERSION = '1.20';
+	$CSS::Tiny::errstr  = '';
+}
+
+# Create an empty object
+sub new { bless {}, shift }
+
+# Create an object from a file
+sub read {
+	my $class = shift;
+
+	# Check the file
+	my $file = shift or return $class->_error( 'You did not specify a file name' );
+	return $class->_error( "The file '$file' does not exist" )          unless -e $file;
+	return $class->_error( "'$file' is a directory, not a file" )       unless -f _;
+	return $class->_error( "Insufficient permissions to read '$file'" ) unless -r _;
+
+	# Read the file
+	local $/ = undef;
+	open( CSS, $file ) or return $class->_error( "Failed to open file '$file': $!" );
+	my $contents = <CSS>;
+	close( CSS );
+
+	$class->read_string( $contents )
+}
+
+# Create an object from a string
+sub read_string {
+	my $self = ref $_[0] ? shift : bless {}, shift;
+
+	# Flatten whitespace and remove /* comment */ style comments
+	my $string = shift;
+	$string =~ tr/\n\t/  /;
+	$string =~ s!/\*.*?\*\/!!g;
+
+	# Split into styles
+	foreach ( grep { /\S/ } split /(?<=\})/, $string ) {
+		unless ( /^\s*([^{]+?)\s*\{(.*)\}\s*$/ ) {
+			return $self->_error( "Invalid or unexpected style data '$_'" );
+		}
+
+		# Split in such a way as to support grouped styles
+		my $style      = $1;
+		my $properties = $2;
+		$style =~ s/\s{2,}/ /g;
+		my @styles = grep { s/\s+/ /g; 1; } grep { /\S/ } split /\s*,\s*/, $style;
+		foreach ( @styles ) { $self->{$_} ||= {} }
+
+		# Split into properties
+		foreach ( grep { /\S/ } split /\;/, $properties ) {
+			unless ( /^\s*(\*?[\w._-]+)\s*:\s*(.*?)\s*$/ ) {
+				return $self->_error( "Invalid or unexpected property '$_' in style '$style'" );
+			}
+			foreach ( @styles ) { $self->{$_}->{lc $1} = $2 }
+		}
+	}
+
+	$self
+}
+
+# Copy an object, using Clone.pm if available
+BEGIN { local $@; eval "use Clone 'clone';"; eval <<'END_PERL' if $@; }
+sub clone {
+	my $self = shift;
+	my $copy = ref($self)->new;
+	foreach my $key ( keys %$self ) {
+		my $section = $self->{$key};
+		$copy->{$key} = {};
+		foreach ( keys %$section ) {
+			$copy->{$key}->{$_} = $section->{$_};
+		}
+	}
+	$copy;
+}
+END_PERL
+
+# Save an object to a file
+sub write {
+	my $self = shift;
+	my $file = shift or return $self->_error( 'No file name provided' );
+
+	# Write the file
+	open( CSS, '>'. $file ) or return $self->_error( "Failed to open file '$file' for writing: $!" );
+	print CSS $self->write_string;
+	close( CSS );
+}
+
+# Save an object to a string
+sub write_string {
+	my $self = shift;
+
+	# Iterate over the styles
+	# Note: We use 'reverse' in the sort to avoid a special case related
+	# to A:hover even though the file ends up backwards and looks funny.
+	# See http://www.w3.org/TR/CSS2/selector.html#dynamic-pseudo-classes
+	my $contents = '';
+	foreach my $style ( reverse sort keys %$self ) {
+		$contents .= "$style {\n";
+		foreach ( sort keys %{ $self->{$style} } ) {
+			$contents .= "\t" . lc($_) . ": $self->{$style}->{$_};\n";
+		}
+		$contents .= "}\n";
+	}
+
+	return $contents;
+}
+
+# Generate a HTML fragment for the CSS
+sub html {
+	my $css = $_[0]->write_string or return '';
+	return "<style type=\"text/css\">\n<!--\n${css}-->\n</style>";
+}
+
+# Generate an xhtml fragment for the CSS
+sub xhtml {
+	my $css = $_[0]->write_string or return '';
+	return "<style type=\"text/css\">\n/* <![CDATA[ */\n${css}/* ]]> */\n</style>";
+}
+
+# Error handling
+sub errstr { $CSS::Tiny::errstr }
+sub _error { $CSS::Tiny::errstr = $_[1]; undef }
+
+1;
+
+__END__
+
 =pod
 
 =head1 NAME
@@ -107,28 +239,10 @@ reference the key C<$CSS-E<gt>{P}-E<gt>{font-family}>.
 
 =head1 METHODS
 
-=cut
-
-use strict;
-
-use vars qw{$VERSION $errstr};
-BEGIN {
-	$VERSION = '1.11';
-	$errstr  = '';
-}
-
-=pod
-
 =head2 new
 
 The constructor C<new> creates and returns an empty C<CSS::Tiny> object.
 
-=cut
-
-sub new { bless {}, shift }
-
-=pod
-
 =head2 read $filename
 
 The C<read> constructor reads a CSS stylesheet, and returns a new
@@ -136,185 +250,59 @@ C<CSS::Tiny> object containing the properties in the file.
 
 Returns the object on success, or C<undef> on error.
 
-=cut
-
-sub read {
-	my $class = shift;
-
-	# Check the file
-	my $file = shift or return $class->_error( 'You did not specify a file name' );
-	return $class->_error( "The file '$file' does not exist" )          unless -e $file;
-	return $class->_error( "'$file' is a directory, not a file" )       unless -f _;
-	return $class->_error( "Insufficient permissions to read '$file'" ) unless -r _;
-
-	# Read the file
-	local $/ = undef;
-	open( CSS, $file ) or return $class->_error( "Failed to open file '$file': $!" );
-	my $contents = <CSS>;
-	close( CSS );
-
-	$class->read_string( $contents )
-}
-
-=pod
-
 =head2 read_string $string
 
 The C<read_string> constructor reads a CSS stylesheet from a string.
 
 Returns the object on success, or C<undef> on error.
 
-=cut
-
-sub read_string {
-	my $self = bless {}, shift;
-
-	# Flatten whitespace and remove /* comment */ style comments
-	my $string = shift;
-	$string =~ tr/\n\t/  /;
-	$string =~ s!/\*.*?\*\/!!g;
-
-	# Split into styles
-	foreach ( grep { /\S/ } split /(?<=\})/, $string ) {
-		unless ( /^\s*([^{]+?)\s*\{(.*)\}\s*$/ ) {
-			return $self->_error( "Invalid or unexpected style data '$_'" );
-		}
-
-		# Split in such a way as to support grouped styles
-		my $style = $1;
-		$style =~ s/\s{2,}/ /g;
-		my @styles = grep { s/\s+/ /g; 1; } grep { /\S/ } split /\s*,\s*/, $style;
-		foreach ( @styles ) { $self->{$_} ||= {} }
-
-		# Split into properties
-		foreach ( grep { /\S/ } split /\;/, $2 ) {
-			unless ( /^\s*([\w._-]+)\s*:\s*(.*?)\s*$/ ) {
-				return $self->_error( "Invalid or unexpected property '$_' in style '$style'" );
-			}
-			foreach ( @styles ) { $self->{$_}->{lc $1} = $2 }
-		}
-	}
-
-	$self
-}
-
-=pod
-
 =head2 clone
 
 The C<clone> method creates an identical copy of an existing C<CSS::Tiny>
 object.
 
-=cut
+=head2 write_string
 
-BEGIN {
-	eval "use Clone 'clone';";
-	eval <<'END_METHOD' if $@;
-sub clone {
-	my $self = shift;
-	my $copy = ref($self)->new;
-	foreach my $key ( keys %$self ) {
-		my $section = $self->{$key};
-		$copy->{$key} = {};
-		foreach ( keys %$section ) {
-			$copy->{$key}->{$_} = $section->{$_};
-		}
-	}
-	$copy;
-}
-END_METHOD
-}
-
-=pod
+Generates the stylesheet for the object and returns it as a string.
 
 =head2 write
 
 The C<write $filename> generates the stylesheet for the properties, and 
 writes it to disk. Returns true on success. Returns C<undef> on error.
 
-=cut
-
-sub write {
-	my $self = shift;
-	my $file = shift or return $self->_error( 'No file name provided' );
-
-	# Write the file
-	open( CSS, '>'. $file ) or return $self->_error( "Failed to open file '$file' for writing: $!" );
-	print CSS $self->write_string;
-	close( CSS );
-
-	1
-}
-
-=pod
-
-=head2 write_string
-
-Generates the stylesheet for the object and returns it as a string.
-
-=cut
-
-sub write_string {
-	my $self = shift;
-
-	# Iterate over the styles
-	# Note: We use 'reverse' in the sort to avoid a special case related
-	# to A:hover. See http://www.w3.org/TR/CSS2/selector.html#dynamic-pseudo-classes
-	my $contents = '';
-	foreach my $style ( reverse sort keys %$self ) {
-		$contents .= "$style {\n";
-		foreach ( sort keys %{ $self->{$style} } ) {
-			$contents .= "\t" . lc($_) . ": $self->{$style}->{$_};\n";
-		}
-		$contents .= "}\n";
-	}
-
-	$contents
-}
-
-=pod
-
 =head2 html
 
 The C<html> method generates the CSS, but wrapped in a C<style> HTML tag,
 so that it can be dropped directly onto a HTML page.
 
-=cut
-
-sub html {
-	my $css = $_[0]->write_string or return '';
-	"<style type=\"text/css\">\n<!--\n${css}-->\n</style>";
-}
-
-=pod
-
 =head2 xhtml
 
 The C<html> method generates the CSS, but wrapped in a C<style> XHTML tag,
 so that it can be dropped directly onto an XHTML page.
 
-=cut
-
-sub xhtml {
-	my $css = $_[0]->write_string or return '';
-	"<style type=\"text/css\">\n/* <![CDATA[ */\n${css}/* ]]> */\n</style>";
-}
-
-=pod
-
 =head2 errstr
 
 When an error occurs, you can retrieve the error message either from the
 C<$CSS::Tiny::errstr> variable, or using the C<errstr> method.
 
-=cut
+=head1 CAVEATS
 
-sub errstr { $errstr }
-sub _error { $errstr = $_[1]; undef }
+=head2 CSS Rule Order
 
-1;
+While the order of rules in CSS is important, this is one of the features
+that is sacrificed to keep things small and dependency-free. If you need
+to preserve order yourself, we recommend that you upgrade to the more
+powerful L<CSS> module.
 
-=pod
+If this is not possible in your case, alternatively it can be done with the
+help of another module such as L<Tie::IxHash>:
+
+    my $css = CSS::Tiny->new;
+    tie %$css, 'Tie::IxHash';
+    $css->read('style.css');
+
+Note: You will also need to remember to add the additional dependency to
+your code or module in this case.
 
 =head1 SUPPORT
 
@@ -326,15 +314,16 @@ For other issues, or commercial enhancement or support, contact the author.
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>cpan@ali.asE<gt>, L<http://ali.as/>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-L<CSS>, L<http://www.w3.org/TR/REC-CSS1>, L<Config::Tiny>
+L<CSS>, L<http://www.w3.org/TR/REC-CSS1>, L<Config::Tiny>, L<http://ali.as/>
 
 =head1 COPYRIGHT
 
-Copyright 2002 - 2005 Adam Kennedy. All rights reserved.
+Copyright 2002 - 2010 Adam Kennedy.
+
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
